==> 0.1.1.tar.gz: lib/presentation/common_widgets/manage_leads_screen.dart <==
import 'dart:convert';

import 'package:flutter/material.dart';
import 'package:lead_management/presentation/utils/locator.dart';

import 'package:shared_preferences/shared_preferences.dart';

import '../utils/appAvatar.dart';
import '../utils/colors.dart';
import '../utils/common_helpdesk_sheet.dart';
import '../utils/hexColors.dart';
import '../utils/text_styling.dart';
import 'Circular_Avtar.dart';


class ManageLeadsSheet extends StatefulWidget {

  final Function(int)? doneCallback;

  ManageLeadsSheet({ this.doneCallback});

  @override
  ManageLeadsSheetState createState() => ManageLeadsSheetState();
}

class ManageLeadsSheetState extends State<ManageLeadsSheet> {
  TextStyleElements? styleElements;
  SharedPreferences prefs = locatorRewards<SharedPreferences>();


  @override
  void initState() {
    super.initState();
    WidgetsBinding.instance!.addPostFrameCallback((timeStamp) {
      // fetchData();
    });
  }

/*  void fetchData() async {
    CategoryListRequest payload = CategoryListRequest();
    payload.businessId = prefs.getInt(Strings.businessId);
    payload.entityType = HELPDESK_ENUMS.status.type;
    payload.pageNumber = 1;
    payload.pageSize = 50;
    var value = await Calls()
        .call(jsonEncode(payload), context, Config.HD_CATEGORY_LIST);
    var res = CategoryListResponse.fromJson(value);
    setState(() {
      selectedItem = res.rows!.firstWhere((element) {
        return element.entityId == widget.item!.currentStatusId;
      });
      statusList.addAll(res.rows!);
    });
  }*/

  @override
  Widget build(BuildContext context) {
    styleElements = TextStyleElements(context);
    return CommonHelpdeskSheet(
      child: Column(mainAxisSize: MainAxisSize.min, children: [
        Padding(
          padding: const EdgeInsets.only(bottom: 16.0),
          child: Stack(
            children: [
              Row(
                mainAxisAlignment: MainAxisAlignment.center,
                children: [
                  Text(
                    "Manage Lead",
                    style: styleElements!
                        .subtitle1ThemeScalable(context)
                        .copyWith(fontWeight: FontWeight.bold),
                  ),
                ],
              ),
              Row(
                mainAxisAlignment: MainAxisAlignment.end,
                children: [
                  InkWell(
                    onTap: () {
                      //  widget.doneCallback!(selectedItem!.entityId!);
                    },
                    child: Padding(
                      padding: const EdgeInsets.only(right: 16.0),
                      child: Text("Done",textAlign: TextAlign.center,),
                    ),
                  )
                ],
              ),
            ],
          ),
        ),

        Expanded(
            child: ListView(
              children: [

                ListTile(
                  leading:  CircularAvatar(
                    height: 30,
                    width: 30,
                    color: HexColor(AppColors.appMainColor),
                    name: "View & Edit details",
                  ),
                  title: Text(
                    "View & Edit details",
                    style: styleElements!.subtitle1ThemeScalable(context),
                  ),

                ),
                ListTile(
                  leading: CircularAvatar(
                    height: 30,
                    width: 30,
                    color: HexColor(AppColors.appMainColor),
                    name: "Add more lead owners",
                  ),
                  title: Text(
                    "Add more lead owners",
                    style: styleElements!.subtitle1ThemeScalable(context),
                  ),

                ),
                ListTile(
                  leading: CircularAvatar(
                    height: 30,
                    width: 30,
                    color: HexColor(AppColors.appMainColor),
                    name: "Update status",
                  ),
                  title: Text(
                    "Update status",
                    style: styleElements!.subtitle1ThemeScalable(context),
                  ),

                ),
                ListTile(
                  leading: IconButton(icon: Icon(Icons.call_end_outlined), onPressed: () {  },),
                  title: Text(
                    "Call",
                    style: styleElements!.subtitle1ThemeScalable(context),
                  ),

                ),
                ListTile(
                  leading:  IconButton(icon: Icon(Icons.meeting_room_outlined), onPressed: () {  },),
                  title: Text(
                    "Create a meeting",
                    style: styleElements!.subtitle1ThemeScalable(context),
                  ),

                ),
              ],
            )
        ),
      ]),
    );
  }
}

==> 0.4.1.tar.gz: lib/presentation/common_widgets/manage_leads_screen.dart <==
import 'dart:convert';

import 'package:flutter/material.dart';
import 'package:lead_management/presentation/utils/locator.dart';

import 'package:shared_preferences/shared_preferences.dart';

import '../utils/appAvatar.dart';
import '../utils/colors.dart';
import '../utils/common_helpdesk_sheet.dart';
import '../utils/hexColors.dart';
import '../utils/text_styling.dart';
import 'Circular_Avtar.dart';


class ManageLeadsSheet extends StatefulWidget {

  final Function(int)? doneCallback;

  ManageLeadsSheet({ this.doneCallback});

  @override
  ManageLeadsSheetState createState() => ManageLeadsSheetState();
}

class ManageLeadsSheetState extends State<ManageLeadsSheet> {
  TextStyleElements? styleElements;
  SharedPreferences prefs = locatorRewards<SharedPreferences>();


  @override
  void initState() {
    super.initState();
    WidgetsBinding.instance!.addPostFrameCallback((timeStamp) {
      // fetchData();
    });
  }

/*  void fetchData() async {
    CategoryListRequest payload = CategoryListRequest();
    payload.businessId = prefs.getInt(Strings.businessId);
    payload.entityType = HELPDESK_ENUMS.status.type;
    payload.pageNumber = 1;
    payload.pageSize = 50;
    var value = await Calls()
        .call(jsonEncode(payload), context, Config.HD_CATEGORY_LIST);
    var res = CategoryListResponse.fromJson(value);
    setState(() {
      selectedItem = res.rows!.firstWhere((element) {
        return element.entityId == widget.item!.currentStatusId;
      });
      statusList.addAll(res.rows!);
    });
  }*/

  @override
  Widget build(BuildContext context) {
    styleElements = TextStyleElements(context);
    return CommonHelpdeskSheet(
      child: Column(mainAxisSize: MainAxisSize.min, children: [
        Padding(
          padding: const EdgeInsets.only(bottom: 16.0),
          child: Stack(
            children: [
              Row(
                mainAxisAlignment: MainAxisAlignment.center,
                children: [
                  Text(
                    "Manage Lead",
                    style: styleElements!
                        .subtitle1ThemeScalable(context)
                        .copyWith(fontWeight: FontWeight.bold),
                  ),
                ],
              ),
              Row(
                mainAxisAlignment: MainAxisAlignment.end,
                children: [
                  InkWell(
                    onTap: () {
                      //  widget.doneCallback!(selectedItem!.entityId!);
                    },
                    child:  Padding(
                      padding: const EdgeInsets.only(right: 16.0),
                      child: Text("Done",textAlign: TextAlign.center,     style: styleElements!.subtitle1ThemeScalable(context).copyWith(
                          fontWeight: FontWeight.bold,
                          color: HexColor((AppColors.blueApp))),),
                    ),
                  )
                ],
              ),
            ],
          ),
        ),

        Expanded(
            child: ListView(
              children: [

                ListTile(
                  leading:  CircularAvatar(
                    height: 30,
                    width: 30,
                    color: HexColor(AppColors.appMainColor),
                    name: "View & Edit details",
                  ),
                  title: Text(
                    "View & Edit details",
                    style: styleElements!.subtitle1ThemeScalable(context),
                  ),

                ),
                ListTile(
                  leading: CircularAvatar(
                    height: 30,
                    width: 30,
                    color: HexColor(AppColors.appMainColor),
                    name: "Add more lead owners",
                  ),
                  title: Text(
                    "Add more lead owners",
                    style: styleElements!.subtitle1ThemeScalable(context),
                  ),

                ),
                ListTile(
                  leading: CircularAvatar(
                    height: 30,
                    width: 30,
                    color: HexColor(AppColors.appMainColor),
                    name: "Update status",
                  ),
                  title: Text(
                    "Update status",
                    style: styleElements!.subtitle1ThemeScalable(context),
                  ),

                ),
                ListTile(
                  leading: Icon(Icons.call_end_outlined),
                  title: Text(
                    "Call",
                    style: styleElements!.subtitle1ThemeScalable(context),
                  ),

                ),
                ListTile(
                  leading: Icon(Icons.meeting_room_outlined),
                  title: Text(
                    "Create a meeting",
                    style: styleElements!.subtitle1ThemeScalable(context),
                  ),

                ),
              ],
            )
        ),
      ]),
    );
  }
}
